networkx\_algo\_common\_subtree.tree\_embedding module
======================================================

.. automodule:: networkx_algo_common_subtree.tree_embedding
   :members:
   :undoc-members:
   :show-inheritance:
